@@ -1,6 +1,5 @@
-# This file was created automatically by SWIG.
+# This file was created automatically by SWIG 1.3.27.
 # Don't modify this file, modify the SWIG interface instead.
-# This file is compatible with both classic and new-style classes.
 
 import _howto
 
@@ -36,12 +35,17 @@ except AttributeError:
 del types
 
 
-class howto_square_ff_sptr(_object):
+def _swig_setattr_nondynamic_method(set):
+    def set_attr(self,name,value):
+        if hasattr(self,name) or (name in ("this", "thisown")):
+            set(self,name,value)
+        else:
+            raise AttributeError("You cannot add attributes to %s" % self)
+    return set_attr
+
+
+class howto_square_ff_sptr(object):
     """Proxy of C++ howto_square_ff_sptr class"""
-    __swig_setmethods__ = {}
-    __setattr__ = lambda self, name, value: _swig_setattr(self, howto_square_ff_sptr, name, value)
-    __swig_getmethods__ = {}
-    __getattr__ = lambda self, name: _swig_getattr(self, howto_square_ff_sptr, name)
     def __repr__(self):
         return "<%s.%s; proxy of C++ boost::shared_ptr<howto_square_ff > instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     def __init__(self, *args):
@@ -49,45 +53,59 @@ class howto_square_ff_sptr(_object):
         __init__(self) -> howto_square_ff_sptr
         __init__(self,  p) -> howto_square_ff_sptr
         """
-        _swig_setattr(self, howto_square_ff_sptr, 'this', _howto.new_howto_square_ff_sptr(*args))
-        _swig_setattr(self, howto_square_ff_sptr, 'thisown', 1)
-    def __deref__(*args): 
+        newobj = _howto.new_howto_square_ff_sptr(*args)
+        self.this = newobj.this
+        self.thisown = 1
+        del newobj.thisown
+    def __deref__(*args):
         """__deref__(self)"""
         return _howto.howto_square_ff_sptr___deref__(*args)
 
-    def name(*args): 
+    def name(*args):
         """name(self) -> string"""
         return _howto.howto_square_ff_sptr_name(*args)
 
-    def input_signature(*args): 
+    def input_signature(*args):
         """input_signature(self) -> gr_io_signature_sptr"""
         return _howto.howto_square_ff_sptr_input_signature(*args)
 
-    def output_signature(*args): 
+    def output_signature(*args):
         """output_signature(self) -> gr_io_signature_sptr"""
         return _howto.howto_square_ff_sptr_output_signature(*args)
 
-    def unique_id(*args): 
+    def unique_id(*args):
         """unique_id(self) -> long"""
         return _howto.howto_square_ff_sptr_unique_id(*args)
 
-    def output_multiple(*args): 
+    def history(*args):
+        """history(self) -> unsigned int"""
+        return _howto.howto_square_ff_sptr_history(*args)
+
+    def output_multiple(*args):
         """output_multiple(self) -> int"""
         return _howto.howto_square_ff_sptr_output_multiple(*args)
 
-    def relative_rate(*args): 
+    def relative_rate(*args):
         """relative_rate(self) -> double"""
         return _howto.howto_square_ff_sptr_relative_rate(*args)
 
-    def check_topology(*args): 
+    def check_topology(*args):
         """check_topology(self, int ninputs, int noutputs) -> bool"""
         return _howto.howto_square_ff_sptr_check_topology(*args)
 
-    def detail(*args): 
+    def start(*args):
+        """start(self) -> bool"""
+        return _howto.howto_square_ff_sptr_start(*args)
+
+    def stop(*args):
+        """stop(self) -> bool"""
+        return _howto.howto_square_ff_sptr_stop(*args)
+
+    def detail(*args):
         """detail(self) -> gr_block_detail_sptr"""
         return _howto.howto_square_ff_sptr_detail(*args)
 
-    def set_detail(*args): 
+    def set_detail(*args):
         """set_detail(self, gr_block_detail_sptr detail)"""
         return _howto.howto_square_ff_sptr_set_detail(*args)
 
@@ -100,9 +118,9 @@ class howto_square_ff_sptr(_object):
 
 class howto_square_ff_sptrPtr(howto_square_ff_sptr):
     def __init__(self, this):
-        _swig_setattr(self, howto_square_ff_sptr, 'this', this)
-        if not hasattr(self,"thisown"): _swig_setattr(self, howto_square_ff_sptr, 'thisown', 0)
-        _swig_setattr(self, howto_square_ff_sptr,self.__class__,howto_square_ff_sptr)
+        self.this = this
+        if not hasattr(self,"thisown"): self.thisown = 0
+        self.__class__ = howto_square_ff_sptr
 _howto.howto_square_ff_sptr_swigregister(howto_square_ff_sptrPtr)
 
 
@@ -116,12 +134,8 @@ howto_square_ff_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name()
 def square_ff(*args):
     """square_ff() -> howto_square_ff_sptr"""
     return _howto.square_ff(*args)
-class howto_square2_ff_sptr(_object):
+class howto_square2_ff_sptr(object):
     """Proxy of C++ howto_square2_ff_sptr class"""
-    __swig_setmethods__ = {}
-    __setattr__ = lambda self, name, value: _swig_setattr(self, howto_square2_ff_sptr, name, value)
-    __swig_getmethods__ = {}
-    __getattr__ = lambda self, name: _swig_getattr(self, howto_square2_ff_sptr, name)
     def __repr__(self):
         return "<%s.%s; proxy of C++ boost::shared_ptr<howto_square2_ff > instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     def __init__(self, *args):
@@ -129,45 +143,59 @@ class howto_square2_ff_sptr(_object):
         __init__(self) -> howto_square2_ff_sptr
         __init__(self,  p) -> howto_square2_ff_sptr
         """
-        _swig_setattr(self, howto_square2_ff_sptr, 'this', _howto.new_howto_square2_ff_sptr(*args))
-        _swig_setattr(self, howto_square2_ff_sptr, 'thisown', 1)
-    def __deref__(*args): 
+        newobj = _howto.new_howto_square2_ff_sptr(*args)
+        self.this = newobj.this
+        self.thisown = 1
+        del newobj.thisown
+    def __deref__(*args):
         """__deref__(self)"""
         return _howto.howto_square2_ff_sptr___deref__(*args)
 
-    def name(*args): 
+    def name(*args):
         """name(self) -> string"""
         return _howto.howto_square2_ff_sptr_name(*args)
 
-    def input_signature(*args): 
+    def input_signature(*args):
         """input_signature(self) -> gr_io_signature_sptr"""
         return _howto.howto_square2_ff_sptr_input_signature(*args)
 
-    def output_signature(*args): 
+    def output_signature(*args):
         """output_signature(self) -> gr_io_signature_sptr"""
         return _howto.howto_square2_ff_sptr_output_signature(*args)
 
-    def unique_id(*args): 
+    def unique_id(*args):
         """unique_id(self) -> long"""
         return _howto.howto_square2_ff_sptr_unique_id(*args)
 
-    def output_multiple(*args): 
+    def history(*args):
+        """history(self) -> unsigned int"""
+        return _howto.howto_square2_ff_sptr_history(*args)
+
+    def output_multiple(*args):
         """output_multiple(self) -> int"""
         return _howto.howto_square2_ff_sptr_output_multiple(*args)
 
-    def relative_rate(*args): 
+    def relative_rate(*args):
         """relative_rate(self) -> double"""
         return _howto.howto_square2_ff_sptr_relative_rate(*args)
 
-    def check_topology(*args): 
+    def check_topology(*args):
         """check_topology(self, int ninputs, int noutputs) -> bool"""
         return _howto.howto_square2_ff_sptr_check_topology(*args)
 
-    def detail(*args): 
+    def start(*args):
+        """start(self) -> bool"""
+        return _howto.howto_square2_ff_sptr_start(*args)
+
+    def stop(*args):
+        """stop(self) -> bool"""
+        return _howto.howto_square2_ff_sptr_stop(*args)
+
+    def detail(*args):
         """detail(self) -> gr_block_detail_sptr"""
         return _howto.howto_square2_ff_sptr_detail(*args)
 
-    def set_detail(*args): 
+    def set_detail(*args):
         """set_detail(self, gr_block_detail_sptr detail)"""
         return _howto.howto_square2_ff_sptr_set_detail(*args)
 
@@ -180,9 +208,9 @@ class howto_square2_ff_sptr(_object):
 
 class howto_square2_ff_sptrPtr(howto_square2_ff_sptr):
     def __init__(self, this):
-        _swig_setattr(self, howto_square2_ff_sptr, 'this', this)
-        if not hasattr(self,"thisown"): _swig_setattr(self, howto_square2_ff_sptr, 'thisown', 0)
-        _swig_setattr(self, howto_square2_ff_sptr,self.__class__,howto_square2_ff_sptr)
+        self.this = this
+        if not hasattr(self,"thisown"): self.thisown = 0
+        self.__class__ = howto_square2_ff_sptr
 _howto.howto_square2_ff_sptr_swigregister(howto_square2_ff_sptrPtr)
 
 
@@ -197,3 +225,4 @@ def square2_ff(*args):
     """square2_ff() -> howto_square2_ff_sptr"""
     return _howto.square2_ff(*args)
 
+
